import Header from './Header';
import { HistoricalImpliedVolatilityChart } from "./HistoricalImpliedVolatilityChart";
import { create$Picker } from './Picker';
import { atom as $, useAtomValue } from 'jotai';
//import './index.css';
//@ts-ignore
import k from './App.module.css';

const baseUrl = 'http://127.0.0.1:8234';

/* The following are wrapped in atoms to prevent re-creating them if App() re-runs. */
const $underlyingsUrl = $(`${baseUrl}/option_quotes/underlyings`);
const $underlyingPicker = create$Picker({$url:$underlyingsUrl});
const $quoteDatePicker = create$Picker({
  $url:       $((get) => `${baseUrl}/option_quotes/${get(get($underlyingPicker).$selectedOption)}/quote_dates`), 
  $isEnabled: $((get) => get(get($underlyingPicker).$selectedOption)!=='')
});
const $strikePicker = create$Picker({
  $url:       $((get) => `${baseUrl}/option_quotes/${get(get($underlyingPicker).$selectedOption)}/${get(get($quoteDatePicker).$selectedOption)}/strikes`), 
  $isEnabled: $((get) => get(get($quoteDatePicker).$selectedOption)!=='' && get(get($underlyingPicker).$selectedOption)!=='')
});
const $frontMonthPicker = create$Picker({
  $url:       $((get) => `${baseUrl}/option_quotes/${get(get($underlyingPicker).$selectedOption)}/${get(get($quoteDatePicker).$selectedOption)}/expirations`), 
  $isEnabled: $((get) => get(get($quoteDatePicker).$selectedOption)!=='' && get(get($underlyingPicker).$selectedOption)!=='')
});
const $backMonthPicker = create$Picker({
  $url:       $((get) => `${baseUrl}/option_quotes/${get(get($underlyingPicker).$selectedOption)}/${get(get($quoteDatePicker).$selectedOption)}/expirations`), 
  $isEnabled: $((get) => get(get($quoteDatePicker).$selectedOption)!=='' && get(get($underlyingPicker).$selectedOption)!=='')
});

function App() {
  const {Picker:UnderlyingPicker} = useAtomValue($underlyingPicker);
  const {Picker:QuoteDatePicker} = useAtomValue($quoteDatePicker);
  const {Picker:StrikePicker} = useAtomValue($frontMonthPicker);
  const {Picker:FrontMonthPicker} = useAtomValue($frontMonthPicker);
  const {Picker:BackMonthPicker} = useAtomValue($backMonthPicker);

  return (
  <div className={k.app}>
    <Header />
    <div className={k.picker}><label>Underlying</label><UnderlyingPicker /></div>
    <div className={k.picker}><label>Quote Date</label><QuoteDatePicker /></div>
    <div className={k.picker}><label>Strike</label><StrikePicker /></div>
    <div className={k.picker}><label>Front Expiration</label><FrontMonthPicker /></div>
    <div className={k.picker}><label>Back Expiration</label><BackMonthPicker /></div>
    <HistoricalImpliedVolatilityChart />
  </div>
  );
}

export default App;