import { useEffect } from "react";
import { atom as $, useAtom, Atom, PrimitiveAtom } from 'jotai';

type PickerInput = { $options?:PrimitiveAtom<Array<string>>, $isLoading?:PrimitiveAtom<boolean>, $selectedOption?:PrimitiveAtom<string>, $url:Atom<string>, $isEnabled?:Atom<boolean> };
export function create$Picker({ $options=$([]), $isLoading=$(false), $selectedOption=$(''), $url=$(''), $isEnabled=$(true) }: PickerInput){
  return $({
    $options,
    $isLoading,
    $selectedOption,
    $url,
    Picker: ()=>{
      const [url, setUrl] = useAtom($url);
      const [options, setOptions] = useAtom($options);
      const [isLoading, setIsLoading] = useAtom($isLoading);
      const [selectedOption, setSelectedOption] = useAtom($selectedOption);
      const [isEnabled, setIsEnabled] = useAtom($isEnabled);

      useEffect(()=>{
        if(isEnabled){
          fetch(url)
          .then(x=>x.json())
          .catch((err)=>['AAPL', 'MSFT', 'GOOG'])
          .then((underlyings_)=>{ setOptions(underlyings_); setIsLoading(false); })
        }
      },[isEnabled, url])
      
      return (
        <div>
          {isLoading
          ?
          <span>Loading...</span>
          :
          <select value={selectedOption} onChange={(e)=>{ setSelectedOption(e.target.value); }}>
            <option key="" value=""></option>
            {options.map((date)=>
              <option key={date} value={date}>{date}</option>
            )}
          </select>
          }
        </div>
      );
    }
  });
}